summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneydatetbl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneydatetbl.h')
-rw-r--r--kmymoney2/widgets/kmymoneydatetbl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/widgets/kmymoneydatetbl.h b/kmymoney2/widgets/kmymoneydatetbl.h
index 96e57ee..7de402d 100644
--- a/kmymoney2/widgets/kmymoneydatetbl.h
+++ b/kmymoney2/widgets/kmymoneydatetbl.h
@@ -75,16 +75,16 @@ public:
* The constructor.
*/
kMyMoneyDateTbl(TQWidget *parent=0,
- TQDate date=TQDate::tqcurrentDate(),
+ TQDate date=TQDate::currentDate(),
const char* name=0, WFlags f=0);
/**
* Returns a recommended size for the widget.
* To save some time, the size of the largest used cell content is
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
* tqsizeHint() simply returns a multiple of maxCell.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Set the font size of the date table.
*/
@@ -75,16 +75,16 @@ public:
* calculated in each paintCell() call, since all calculations have
* to be done there anyway. The size is stored in maxCell. The
- * tqsizeHint() simply returns a multiple of maxCell.
+ * sizeHint() simply returns a multiple of maxCell.
*/